Custom

Struct Custom 

#[doc(hidden)]
#[repr(align(4))]
pub struct Custom { kind: ErrorKind, error: NonNull<dyn Error + Send + Sync>, error_drop: unsafe fn(NonNull<dyn Error + Send + Sync>), outer_drop: unsafe fn(NonNull<Self>), }
🔬This is a nightly-only experimental API. (core_io_internals)
A user-created allocated error.

Fields

kind: ErrorKind
🔬This is a nightly-only experimental API. (core_io_internals)
error: NonNull<dyn Error + Send + Sync>
🔬This is a nightly-only experimental API. (core_io_internals)

Box<dyn Error + ...> without alloc.

error_drop: unsafe fn(NonNull<dyn Error + Send + Sync>)
🔬This is a nightly-only experimental API. (core_io_internals)
outer_drop: unsafe fn(NonNull<Self>)
🔬This is a nightly-only experimental API. (core_io_internals)

Call to drop a pointer to Custom.

Implementations

Source

impl Custom

pub unsafe fn from_raw( kind: ErrorKind, error: NonNull<dyn Error + Send + Sync>, error_drop: unsafe fn(NonNull<dyn Error + Send + Sync>), outer_drop: unsafe fn(NonNull<Self>), ) -> Custom

🔬This is a nightly-only experimental API. (core_io_internals)
Safety
  • error must be valid for up to a static lifetime, and own its pointee.
  • error_drop must be safe to call for the pointer error exactly once.
  • outer_drop must be safe to call on a pointer to this instance of Custom (the pointer is likely stored within a CustomOwner).
pub fn into_raw(self) -> NonNull<dyn Error + Send + Sync>

🔬This is a nightly-only experimental API. (core_io_internals)
fn error_ref(&self) -> &(dyn Error + Send + Sync + 'static)

🔬This is a nightly-only experimental API. (core_io #154046)
fn error_mut(&mut self) -> &mut (dyn Error + Send + Sync + 'static)

🔬This is a nightly-only experimental API. (core_io #154046)